@@ -41,6 +41,7 @@ from isbn import ISBN
 from jsonschema import Draft4Validator, RefResolver, draft4_format_checker
 from jsonschema import validate as jsonschema_validate
 from pkg_resources import resource_filename
+from pytz import UnknownTimeZoneError, timezone
 from six.moves.urllib.parse import urlsplit
 from unidecode import unidecode
 
@@ -65,7 +66,7 @@ _RE_LICENSE_URL = re.compile(
     r'^/licenses/(?P<sublicense>[-\w]*)(?:/(?P<version>[\.\d]*))?'
 )
 _RE_VOLUME_STARTS_WITH_A_LETTER = re.compile(
-    r'^(?P<letter>[A-Z])(?P<volume>\d[\dA-Z]*$)', re.IGNORECASE
+    r'^(?P<letter>[A-Z])(?P<volume>\d[\dA-Z-]*$)', re.IGNORECASE
 )
 _RE_VOLUME_ENDS_WITH_A_LETTER = re.compile(
     r'(?P<volume>\d+)(?P<letter>[A-Z])$', re.IGNORECASE
@@ -86,12 +87,12 @@ _RE_AUTHORS_UID = {
 # Matches new style arXiv ID, with an old-style class specification
 # (Malformed, but appears in APS records)
 RE_ARXIV_POST_2007_CLASS = re.compile(
-    "(arxiv:)?((?P<category>(?:[a-z\-]+)(?:\.[a-z]{2})?)/)?(?P<identifier>\d{4}\.\d{4,5})(v\d+)?$",
+    r"(arxiv:)?((?P<category>(?:[a-z-]+)(?:\.[a-z]{2})?)/)?(?P<identifier>\d{4}\.\d{4,5})(v\d+)?$",
     flags=re.I
 )
 
 RE_ARXIV_PRE_2007_CLASS = re.compile(
-    "(arxiv:)?(?P<category>(?P<extraidentifier>[a-z\-]+)(?:\.[a-z]{2})?)/(?P<identifier>\d{4}\d+)(v\d+)?$",
+    r"(arxiv:)?(?P<category>(?P<extraidentifier>[a-z-]+)(?:\.[a-z]{2})?)/(?P<identifier>\d{4}\d+)(v\d+)?$",
     flags=re.I
 )
 
@@ -328,7 +329,7 @@ _JOURNALS_WITH_YEAR_ADDED_TO_VOLUME = {
 EMPTIES = [None, '', [], {}]
 
 _BLEACH_CONFIG = {
-    'tags': ['a', 'b', 'br', 'em', 'i', 'li', 'ol', 'p', 'strong', 'ul'],
+    'tags': ['a', 'b', 'br', 'div', 'em', 'i', 'li', 'ol', 'p', 'strong', 'ul'],
     'attributes': {'a': ['href', 'title']},
     'strip': True,
     'filters': [LinkifyFilter],
@@ -631,6 +632,7 @@ inspire_format_checker.checks('uri-reference', raises=ValueError)(
     partial(rfc3987.parse, rule='URI_reference')
 )
 inspire_format_checker.checks('orcid')(is_orcid)
+inspire_format_checker.checks('timezone', raises=UnknownTimeZoneError)(timezone)
 
 
 def _load_schema_for_record(data, schema=None):
@@ -840,7 +842,8 @@ def convert_old_publication_info_to_new(publication_infos):
 
         journal_volume = _publication_info.get('journal_volume')
 
-        if journal_title in _JOURNALS_WITH_YEAR_ADDED_TO_VOLUME and journal_volume and len(journal_volume) == 4:
+        if journal_title and journal_title.upper() in _JOURNALS_WITH_YEAR_ADDED_TO_VOLUME and \
+                journal_volume and len(journal_volume) == 4:
             try:
                 was_last_century = int(journal_volume[:2]) > 50
             except ValueError:
@@ -917,8 +920,8 @@ def convert_new_publication_info_to_old(publication_infos):
         journal_volume = _publication_info.get('journal_volume')
         year = _publication_info.get('year')
 
-        if (journal_title in _JOURNALS_WITH_YEAR_ADDED_TO_VOLUME and year and
-                journal_volume and len(journal_volume) == 2):
+        if (journal_title and journal_title.upper() in _JOURNALS_WITH_YEAR_ADDED_TO_VOLUME and
+                year and journal_volume and len(journal_volume) == 2):
             two_digit_year = str(year)[2:]
             _publication_info['journal_volume'] = ''.join([two_digit_year, journal_volume])
             result.append(_publication_info)
@@ -927,15 +930,15 @@ def convert_new_publication_info_to_old(publication_infos):
         if journal_title and journal_volume:
             match = _RE_TITLE_ENDS_WITH_A_LETTER.match(journal_title)
             if match and _needs_a_hidden_pubnote(journal_title, journal_volume):
-                _publication_info['journal_title'] = match.group('title')
+                _publication_info['journal_title'] = match.group('title').strip()
                 _publication_info['journal_volume'] = journal_volume + match.group('letter')
                 result.append(_publication_info)
                 _publication_info = copy.deepcopy(publication_info)
                 _publication_info['hidden'] = True
-                _publication_info['journal_title'] = match.group('title')
+                _publication_info['journal_title'] = match.group('title').strip()
                 _publication_info['journal_volume'] = match.group('letter') + journal_volume
             elif match and journal_title not in _JOURNALS_ALREADY_ENDING_WITH_A_LETTER:
-                _publication_info['journal_title'] = match.group('title')
+                _publication_info['journal_title'] = match.group('title').strip()
                 _publication_info['journal_volume'] = match.group('letter') + journal_volume
 
         result.append(_publication_info)
